@@ -8,9 +8,10 @@ import os
 import shutil
 import subprocess
 import sys
+from collections.abc import Generator, Mapping
 from contextlib import ExitStack
 from pathlib import Path
-from typing import Dict, Generator, List, Mapping, Optional, Tuple, Union
+from typing import Optional, Union
 
 import pytest
 
@@ -83,11 +84,11 @@ def env_accepts_null() -> bool:
 
 
 def get_main_output(
-    args: List[str],
+    args: list[str],
     replacement_env: Optional[Mapping[str, str]] = None,
     extra_env: Optional[Mapping[str, str]] = None,
     monkeypatch: Optional[pytest.MonkeyPatch] = None,
-) -> Tuple[Optional[int], str, str]:
+) -> tuple[Optional[int], str, str]:
     """Run cwltool main.
 
     args: the command line args to call it with
@@ -127,13 +128,13 @@ def get_main_output(
 
 def get_tool_env(
     tmp_path: Path,
-    flag_args: List[str],
+    flag_args: list[str],
     inputs_file: Optional[str] = None,
     replacement_env: Optional[Mapping[str, str]] = None,
     extra_env: Optional[Mapping[str, str]] = None,
     monkeypatch: Optional[pytest.MonkeyPatch] = None,
     runtime_env_accepts_null: Optional[bool] = None,
-) -> Dict[str, str]:
+) -> dict[str, str]:
     """Get the env vars for a tool's invocation."""
     # GNU env accepts the -0 option to end each variable's
     # printing with "\0". No such luck on BSD-ish.
